@@ -60,9 +60,9 @@ function [C] = bim2a_reaction(mesh,delta,zeta)
 
   if !( isvector(delta) && isvector(zeta) )
     error("bim2a_reaction: coefficients are not valid vectors.");
-  elseif length(delta) != nelem
+  elseif (numel (delta) != nelem)
     error("bim2a_: length of alpha is not equal to the number of elements.");
-  elseif length(zeta) != nnodes
+  elseif (numel (zeta) != nnodes)
     error("bim2a_: length of gamma is not equal to the number of nodes.");
   endif
 
@@ -101,4 +101,4 @@ endfunction
 %!test
 % [C1] = bim2a_reaction(mesh,3*delta,zeta);
 % [C2] = bim2a_reaction(mesh,3,1);
-% assert(C1,C2);
\ No newline at end of file
+% assert(C1,C2);
